@@ -55,7 +55,7 @@ const EditFieldType = {
     ADDRESS: 3
 };
 
-const _WIKI_BASE = 'http://wiki.openstreetmap.org/wiki/Key:';
+const _WIKI_BASE = 'https://wiki.openstreetmap.org/wiki/Key:';
 
 let _osmWikipediaRewriteFunc = function(text) {
     let wikipediaArticleFormatted = OSMUtils.getWikipediaOSMArticleFormatFromUrl(text);
@@ -337,6 +337,7 @@ const OSMEditDialog = new Lang.Class({
     _onTypeClicked: function() {
         this._cancelButton.visible = false;
         this._backButton.visible = true;
+        this._nextButton.visible = false;
         this._headerBar.title = _("Select Type");
         this._stack.visible_child_name = 'select-type';
     },
@@ -354,6 +355,7 @@ const OSMEditDialog = new Lang.Class({
         /* go back to the editing stack page */
         this._backButton.visible = false;
         this._cancelButton.visible = true;
+        this._nextButton.visible = true;
         this._stack.visible_child_name = 'editor';
         this._headerBar.title = this._originalTitle;
 
@@ -469,6 +471,7 @@ const OSMEditDialog = new Lang.Class({
     _onBackClicked: function() {
         this._backButton.visible = false;
         this._cancelButton.visible = true;
+        this._nextButton.visible = true;
         this._nextButton.label = _("Next");
         this._stack.set_visible_child_name('editor');
         this._isEditing = true;
